@@ -30,10 +30,18 @@ warnings.filterwarnings("ignore")
 
 class accuinsight(Common):
     def __init__(self):
-        super(Common, self).__init__()
+        super().__init__()
+
+    def get_data_info(self):
+        global save_path, StorageInfo, target_name
+        save_path = self.save_path
+        StorageInfo = self.StorageInfo
+        target_name = self.target_name
 
     class add_experiment(object):
         def __init__(self, model_name, *args, model_monitor=False):
+            accuinsight.get_data_info(accuinsight())
+
             if model_monitor:
                 self.shap_on = True
                 logging.info('Using add_experiment(model_monitor=True)')
@@ -150,7 +158,7 @@ class accuinsight(Common):
             
             if self.shap_on:
                 try:
-                    self.feature_name = get.feature_name(self.save_path, self.StorageInfo, self.target_name)
+                    self.feature_name = get.feature_name(save_path, StorageInfo, target_name)
                 except:
                     self.feature_name = None
                 self.run_id = self.fitted_model + '-' + self.run_id
