@@ -29,12 +29,7 @@ warnings.filterwarnings("ignore")
 
 class accuinsight(Common):
     def __init__(self):
-        self.BucketInfo = None
-        self.endpoint = None
-        self.thresholds = None
-        self.token = None
-        self.channel_id = None
-        self.message = None
+        super().__init__()
 
     def autolog(self, tag=None, best_weights=False):
         global description, endpoint, var_model_file_path, message, thresholds, token, channel_id
