@@ -5,8 +5,6 @@ import warnings
 from collections import OrderedDict
 
 import gorilla
-from slack_sdk import WebClient
-from slack_sdk.errors import SlackApiError
 import numpy as np
 import tensorflow
 from tensorflow.keras.callbacks import CSVLogger
@@ -33,7 +31,7 @@ warnings.filterwarnings("ignore")
 
 class accuinsight(Common):
     def __init__(self):
-        super(Common, self).__init__()
+        super().__init__()
 
     def autolog(self, tag=None, best_weights=False, model_monitor=False):
         global description, endpoint, var_model_file_path, message, thresholds, token, channel_id, best_weights_on, run_id, shap_on, feature_name
