@@ -4,6 +4,7 @@ from Accuinsight.modeler.entities.monitoring_deploy_log import DeployLog
 from Accuinsight.modeler.entities.monitoring_deploy_alarm import DeployAlarm
 from Accuinsight.modeler.clients.modeler_api import DeployLogRestApi
 from Accuinsight.modeler.core.LcConst import LcConst
+from Accuinsight.modeler.utils.os_getenv import get_os_env
 
 
 class AddDeployLog:
@@ -12,11 +13,13 @@ class AddDeployLog:
     """
 
     def __init__(self):
+        env_value = get_os_env('ENV')
+
         self.deploy_log = DeployLog()
         self.deploy_alarm = DeployAlarm()
-        self.deploy_log_api = DeployLogRestApi(LcConst.BACK_END_API_URL,
-                                               LcConst.BACK_END_API_PORT,
-                                               LcConst.BACK_END_API_URI)
+        self.deploy_log_api = DeployLogRestApi(env_value[LcConst.BACK_END_API_URL],
+                                               env_value[LcConst.BACK_END_API_PORT],
+                                               env_value[LcConst.BACK_END_API_URI])
         self.swagger = False
 
     def set_request(self, request):
