@@ -126,26 +126,34 @@ class from_model(object):
 def is_classification(model_name):
     if hasattr(model_name.loss, 'get_config'):      # tensorflow
         if model_name.loss.get_config()['name'] in lossFuncInfo.CLASSIFICATION:
-            return(True)
+            return True
     
         elif model_name.loss.get_config()['name'] in lossFuncInfo.REGRESSION:
-            return(False)
+            return False
     
         else:
             raise ValueError('현재 설정한 loss는 지원되지 않습니다. 관리자에게 문의하십시오.')
         
     else:                                          # keras
         if model_name.loss in lossFuncInfo.CLASSIFICATION:
-            return(True)
+            return True
 
         elif model_name.loss in lossFuncInfo.REGRESSION:
-            return(False)
+            return False
 
         else:
             raise ValueError('현재 설정한 loss는 지원되지 않습니다. 관리자에게 문의하십시오.')
-            
-def feature_name(savedPath, bucketInfo, targetName):
-    fileType = bucketInfo['fileName'].split('.')[1]
+
+
+def feature_name(savedPath, StorageInfo, targetName):
+    if StorageInfo is None:
+        fileType = savedPath.split('.')[-1]
+
+    elif 'host' in StorageInfo:  # HDFS
+        fileType = StorageInfo['filePath'].split('.')[1]
+
+    else:  # AWS S3
+        fileType = StorageInfo['fileName'].split('.')[1]
         
     if fileType == 'json':
         with open(savedPath) as jsonFile:
@@ -153,11 +161,11 @@ def feature_name(savedPath, bucketInfo, targetName):
         feature_name = list(json_data.keys())
     elif fileType == 'csv':
         feature_name = list(pd.read_csv(savedPath).columns)
-        if 'Unnamed: 0' in feature_name:
+        if 'Unnamed: 0' in feature_name and feature_name[0]=='Unnamed: 0':
             feature_name.remove('Unnamed: 0')
     else:
         raise TypeError('{type}은 지원하지 않는 데이터 형식입니다. 현재 지원하는 데이터 형식은 json과 csv입니다.'.format(type=fileType))
     
     if targetName in feature_name:
         feature_name.remove(targetName)
-    return(feature_name)
+    return feature_name
