@@ -44,11 +44,11 @@ class WorkspaceRunLog:
     @property
     def stop_timeout(self):
         """Workspace stop timeout."""
-        return self._stop_flag
+        return self._stop_timeout
 
     @stop_timeout.setter
     def stop_timeout(self, stop_timeout):
-        self._stop_flag = stop_timeout
+        self._stop_timeout = stop_timeout
 
     @classmethod
     def from_proto(cls, proto):
